Class: Google::Apis::FirebasehostingV1beta1::LiveMigrationStep

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebasehosting_v1beta1/classes.rb,
lib/google/apis/firebasehosting_v1beta1/representations.rb,
lib/google/apis/firebasehosting_v1beta1/representations.rb

Overview

A set of updates including ACME challenges and DNS records that allow Hosting to create an SSL certificate and establish project ownership for your domain name before you direct traffic to Hosting servers. Use these updates to facilitate zero downtime migrations to Hosting from other services. After you' ve made the recommended updates, check your custom domain's ownershipState and certState. To avoid downtime, they should be OWNERSHIP_ACTIVE and CERT_ACTIVE, respectively, before you update your A and AAAA records.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LiveMigrationStep

Returns a new instance of LiveMigrationStep.



1200
1201
1202
# File 'lib/google/apis/firebasehosting_v1beta1/classes.rb', line 1200

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cert_verificationGoogle::Apis::FirebasehostingV1beta1::CertVerification

A set of ACME challenges you can use to allow Hosting to create an SSL certificate for your domain name before directing traffic to Hosting servers. Use either the DNS or HTTP challenge; it's not necessary to provide both. Corresponds to the JSON property certVerification



1177
1178
1179
# File 'lib/google/apis/firebasehosting_v1beta1/classes.rb', line 1177

def cert_verification
  @cert_verification
end

#dns_updatesGoogle::Apis::FirebasehostingV1beta1::DnsUpdates

A set of DNS record updates that you should make to allow Hosting to serve secure content in response to requests against your domain name. These updates present the current state of your domain name's DNS records when Hosting last queried them, and the desired set of records that Hosting needs to see before your custom domain can be fully active. Corresponds to the JSON property dnsUpdates



1186
1187
1188
# File 'lib/google/apis/firebasehosting_v1beta1/classes.rb', line 1186

def dns_updates
  @dns_updates
end

#issuesArray<Google::Apis::FirebasehostingV1beta1::Status>

Output only. Issues that prevent the current step from completing. Corresponds to the JSON property issues



1191
1192
1193
# File 'lib/google/apis/firebasehosting_v1beta1/classes.rb', line 1191

def issues
  @issues
end

#stateString

Output only. The state of the live migration step, indicates whether you should work to complete the step now, in the future, or have already completed it. Corresponds to the JSON property state

Returns:

  • (String)


1198
1199
1200
# File 'lib/google/apis/firebasehosting_v1beta1/classes.rb', line 1198

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1205
1206
1207
1208
1209
1210
# File 'lib/google/apis/firebasehosting_v1beta1/classes.rb', line 1205

def update!(**args)
  @cert_verification = args[:cert_verification] if args.key?(:cert_verification)
  @dns_updates = args[:dns_updates] if args.key?(:dns_updates)
  @issues = args[:issues] if args.key?(:issues)
  @state = args[:state] if args.key?(:state)
end