Class: Google::Apis::FirebasehostingV1beta1::Site

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebasehosting_v1beta1/classes.rb,
lib/google/apis/firebasehosting_v1beta1/representations.rb,
lib/google/apis/firebasehosting_v1beta1/representations.rb

Overview

A Site represents a Firebase Hosting site.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Site

Returns a new instance of Site.



1619
1620
1621
# File 'lib/google/apis/firebasehosting_v1beta1/classes.rb', line 1619

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#app_idString

Optional. The ID of a Web App associated with the Hosting site. Corresponds to the JSON property appId

Returns:

  • (String)


1588
1589
1590
# File 'lib/google/apis/firebasehosting_v1beta1/classes.rb', line 1588

def app_id
  @app_id
end

#default_urlString

Output only. The default URL for the Hosting site. Corresponds to the JSON property defaultUrl

Returns:

  • (String)


1593
1594
1595
# File 'lib/google/apis/firebasehosting_v1beta1/classes.rb', line 1593

def default_url
  @default_url
end

#labelsHash<String,String>

Optional. User-specified labels for the Hosting site. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1598
1599
1600
# File 'lib/google/apis/firebasehosting_v1beta1/classes.rb', line 1598

def labels
  @labels
end

#nameString

Output only. The fully-qualified resource name of the Hosting site, in the format: projects/PROJECT_IDENTIFIER/sites/SITE_ID PROJECT_IDENTIFIER: the Firebase project's ProjectNumber (recommended) or its ProjectId. Learn more about using project identifiers in Google's AIP 2510 standard. Corresponds to the JSON property name

Returns:

  • (String)


1610
1611
1612
# File 'lib/google/apis/firebasehosting_v1beta1/classes.rb', line 1610

def name
  @name
end

#typeString

Output only. The type of Hosting site. Every Firebase project has a DEFAULT_SITE, which is created when Hosting is provisioned for the project. All additional sites are USER_SITE. Corresponds to the JSON property type

Returns:

  • (String)


1617
1618
1619
# File 'lib/google/apis/firebasehosting_v1beta1/classes.rb', line 1617

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1624
1625
1626
1627
1628
1629
1630
# File 'lib/google/apis/firebasehosting_v1beta1/classes.rb', line 1624

def update!(**args)
  @app_id = args[:app_id] if args.key?(:app_id)
  @default_url = args[:default_url] if args.key?(:default_url)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @type = args[:type] if args.key?(:type)
end