Class: Google::Apis::FirebasehostingV1beta1::UndeleteCustomDomainRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebasehosting_v1beta1/classes.rb,
lib/google/apis/firebasehosting_v1beta1/representations.rb,
lib/google/apis/firebasehosting_v1beta1/representations.rb

Overview

The request sent to UndeleteCustomDomain.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UndeleteCustomDomainRequest

Returns a new instance of UndeleteCustomDomainRequest.



1721
1722
1723
# File 'lib/google/apis/firebasehosting_v1beta1/classes.rb', line 1721

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

A tag that represents the state of the CustomDomain as you know it. If present, the supplied tag must match the current value on your CustomDomain, or the request fails. Corresponds to the JSON property etag

Returns:

  • (String)


1712
1713
1714
# File 'lib/google/apis/firebasehosting_v1beta1/classes.rb', line 1712

def etag
  @etag
end

#validate_onlyBoolean Also known as: validate_only?

If true, Hosting validates that it's possible to complete your request but doesn't actually delete the CustomDomain. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


1718
1719
1720
# File 'lib/google/apis/firebasehosting_v1beta1/classes.rb', line 1718

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1726
1727
1728
1729
# File 'lib/google/apis/firebasehosting_v1beta1/classes.rb', line 1726

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end