Class: Google::Apis::FirebasehostingV1beta1::ListReleasesResponse
- Inherits:
-
Object
- Object
- Google::Apis::FirebasehostingV1beta1::ListReleasesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebasehosting_v1beta1/classes.rb,
lib/google/apis/firebasehosting_v1beta1/representations.rb,
lib/google/apis/firebasehosting_v1beta1/representations.rb
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
The pagination token, if more results exist beyond the ones in this response.
-
#releases ⇒ Array<Google::Apis::FirebasehostingV1beta1::Release>
The list of hashes of files that still need to be uploaded, if any exist.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListReleasesResponse
constructor
A new instance of ListReleasesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListReleasesResponse
Returns a new instance of ListReleasesResponse.
1070 1071 1072 |
# File 'lib/google/apis/firebasehosting_v1beta1/classes.rb', line 1070 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
The pagination token, if more results exist beyond the ones in this response.
Include this token in your next call to ListReleases. Page tokens are short-
lived and should not be stored.
Corresponds to the JSON property nextPageToken
1063 1064 1065 |
# File 'lib/google/apis/firebasehosting_v1beta1/classes.rb', line 1063 def next_page_token @next_page_token end |
#releases ⇒ Array<Google::Apis::FirebasehostingV1beta1::Release>
The list of hashes of files that still need to be uploaded, if any exist.
Corresponds to the JSON property releases
1068 1069 1070 |
# File 'lib/google/apis/firebasehosting_v1beta1/classes.rb', line 1068 def releases @releases end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1075 1076 1077 1078 |
# File 'lib/google/apis/firebasehosting_v1beta1/classes.rb', line 1075 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @releases = args[:releases] if args.key?(:releases) end |