Class: Google::Apis::FirebasehostingV1beta1::Rewrite
- Inherits:
-
Object
- Object
- Google::Apis::FirebasehostingV1beta1::Rewrite
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebasehosting_v1beta1/classes.rb,
lib/google/apis/firebasehosting_v1beta1/representations.rb,
lib/google/apis/firebasehosting_v1beta1/representations.rb
Overview
A Rewrite
specifies a URL pattern that, if matched to the request URL path, triggers
Hosting to respond as if the service were given the specified destination URL.
Instance Attribute Summary collapse
-
#dynamic_links ⇒ Boolean
(also: #dynamic_links?)
The request will be forwarded to Firebase Dynamic Links.
-
#function ⇒ String
The function to proxy requests to.
-
#function_region ⇒ String
Optional.
-
#glob ⇒ String
The user-supplied glob to match against the request URL path.
-
#path ⇒ String
The URL path to rewrite the request to.
-
#regex ⇒ String
The user-supplied RE2 regular expression to match against the request URL path.
-
#run ⇒ Google::Apis::FirebasehostingV1beta1::CloudRunRewrite
A configured rewrite that directs requests to a Cloud Run service.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Rewrite
constructor
A new instance of Rewrite.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Rewrite
Returns a new instance of Rewrite.
1497 1498 1499 |
# File 'lib/google/apis/firebasehosting_v1beta1/classes.rb', line 1497 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dynamic_links ⇒ Boolean Also known as: dynamic_links?
The request will be forwarded to Firebase Dynamic Links.
Corresponds to the JSON property dynamicLinks
1457 1458 1459 |
# File 'lib/google/apis/firebasehosting_v1beta1/classes.rb', line 1457 def dynamic_links @dynamic_links end |
#function ⇒ String
The function to proxy requests to. Must match the exported function name
exactly.
Corresponds to the JSON property function
1464 1465 1466 |
# File 'lib/google/apis/firebasehosting_v1beta1/classes.rb', line 1464 def function @function end |
#function_region ⇒ String
Optional. Specify a Cloud region for rewritten Functions invocations. If not
provided, defaults to us-central1.
Corresponds to the JSON property functionRegion
1470 1471 1472 |
# File 'lib/google/apis/firebasehosting_v1beta1/classes.rb', line 1470 def function_region @function_region end |
#glob ⇒ String
The user-supplied glob to match against the request URL path.
Corresponds to the JSON property glob
1476 1477 1478 |
# File 'lib/google/apis/firebasehosting_v1beta1/classes.rb', line 1476 def glob @glob end |
#path ⇒ String
The URL path to rewrite the request to.
Corresponds to the JSON property path
1481 1482 1483 |
# File 'lib/google/apis/firebasehosting_v1beta1/classes.rb', line 1481 def path @path end |
#regex ⇒ String
The user-supplied RE2 regular expression to match against the request URL path.
Corresponds to the JSON property regex
1486 1487 1488 |
# File 'lib/google/apis/firebasehosting_v1beta1/classes.rb', line 1486 def regex @regex end |
#run ⇒ Google::Apis::FirebasehostingV1beta1::CloudRunRewrite
A configured rewrite that directs requests to a Cloud Run service. If the
Cloud Run service does not exist when setting or updating your Firebase
Hosting configuration, then the request fails. Any errors from the Cloud Run
service are passed to the end user (for example, if you delete a service, any
requests directed to that service receive a 404 error).
Corresponds to the JSON property run
1495 1496 1497 |
# File 'lib/google/apis/firebasehosting_v1beta1/classes.rb', line 1495 def run @run end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1502 1503 1504 1505 1506 1507 1508 1509 1510 |
# File 'lib/google/apis/firebasehosting_v1beta1/classes.rb', line 1502 def update!(**args) @dynamic_links = args[:dynamic_links] if args.key?(:dynamic_links) @function = args[:function] if args.key?(:function) @function_region = args[:function_region] if args.key?(:function_region) @glob = args[:glob] if args.key?(:glob) @path = args[:path] if args.key?(:path) @regex = args[:regex] if args.key?(:regex) @run = args[:run] if args.key?(:run) end |