Class: Google::Apis::FirebasehostingV1beta1::SiteConfig
- Inherits:
-
Object
- Object
- Google::Apis::FirebasehostingV1beta1::SiteConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebasehosting_v1beta1/classes.rb,
lib/google/apis/firebasehosting_v1beta1/representations.rb,
lib/google/apis/firebasehosting_v1beta1/representations.rb
Overview
A SiteConfig contains metadata associated with a specific site that controls
Firebase Hosting serving behavior
Instance Attribute Summary collapse
-
#cloud_logging_enabled ⇒ Boolean
(also: #cloud_logging_enabled?)
Whether or not web requests made by site visitors are logged via Cloud Logging.
-
#max_versions ⇒ Fixnum
The number of FINALIZED versions that will be held for a site before automatic deletion.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SiteConfig
constructor
A new instance of SiteConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SiteConfig
Returns a new instance of SiteConfig.
1653 1654 1655 |
# File 'lib/google/apis/firebasehosting_v1beta1/classes.rb', line 1653 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cloud_logging_enabled ⇒ Boolean Also known as: cloud_logging_enabled?
Whether or not web requests made by site visitors are logged via Cloud Logging.
Corresponds to the JSON property cloudLoggingEnabled
1641 1642 1643 |
# File 'lib/google/apis/firebasehosting_v1beta1/classes.rb', line 1641 def cloud_logging_enabled @cloud_logging_enabled end |
#max_versions ⇒ Fixnum
The number of FINALIZED versions that will be held for a site before automatic
deletion. When a new version is deployed, content for versions in storage in
excess of this number will be deleted, and will no longer be billed for
storage usage. Oldest versions will be deleted first; sites are created with
an unlimited number of max_versions by default.
Corresponds to the JSON property maxVersions
1651 1652 1653 |
# File 'lib/google/apis/firebasehosting_v1beta1/classes.rb', line 1651 def max_versions @max_versions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1658 1659 1660 1661 |
# File 'lib/google/apis/firebasehosting_v1beta1/classes.rb', line 1658 def update!(**args) @cloud_logging_enabled = args[:cloud_logging_enabled] if args.key?(:cloud_logging_enabled) @max_versions = args[:max_versions] if args.key?(:max_versions) end |