Class: Google::Apis::FirebasehostingV1beta1::Version
- Inherits:
-
Object
- Object
- Google::Apis::FirebasehostingV1beta1::Version
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebasehosting_v1beta1/classes.rb,
lib/google/apis/firebasehosting_v1beta1/representations.rb,
lib/google/apis/firebasehosting_v1beta1/representations.rb
Overview
A Version is a configuration and a collection of static files which
determine how a site is displayed.
Instance Attribute Summary collapse
-
#config ⇒ Google::Apis::FirebasehostingV1beta1::ServingConfig
The configuration for how incoming requests to a site should be routed and processed before serving content.
-
#create_time ⇒ String
Output only.
-
#create_user ⇒ Google::Apis::FirebasehostingV1beta1::ActingUser
Contains metadata about the user who performed an action, such as creating a release or finalizing a version.
-
#delete_time ⇒ String
Output only.
-
#delete_user ⇒ Google::Apis::FirebasehostingV1beta1::ActingUser
Contains metadata about the user who performed an action, such as creating a release or finalizing a version.
-
#file_count ⇒ Fixnum
Output only.
-
#finalize_time ⇒ String
Output only.
-
#finalize_user ⇒ Google::Apis::FirebasehostingV1beta1::ActingUser
Contains metadata about the user who performed an action, such as creating a release or finalizing a version.
-
#labels ⇒ Hash<String,String>
The labels used for extra metadata and/or filtering.
-
#name ⇒ String
The fully-qualified resource name for the version, in the format: sites/ SITE_ID/versions/VERSION_ID This name is provided in the response body when you call
CreateVersion. -
#status ⇒ String
The deploy status of the version.
-
#version_bytes ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Version
constructor
A new instance of Version.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Version
Returns a new instance of Version.
1815 1816 1817 |
# File 'lib/google/apis/firebasehosting_v1beta1/classes.rb', line 1815 def initialize(**args) update!(**args) end |
Instance Attribute Details
#config ⇒ Google::Apis::FirebasehostingV1beta1::ServingConfig
The configuration for how incoming requests to a site should be routed and
processed before serving content. The URL request paths are matched against
the specified URL patterns in the configuration, then Hosting applies the
applicable configuration according to a specific priority order.
Corresponds to the JSON property config
1744 1745 1746 |
# File 'lib/google/apis/firebasehosting_v1beta1/classes.rb', line 1744 def config @config end |
#create_time ⇒ String
Output only. The time at which the version was created.
Corresponds to the JSON property createTime
1749 1750 1751 |
# File 'lib/google/apis/firebasehosting_v1beta1/classes.rb', line 1749 def create_time @create_time end |
#create_user ⇒ Google::Apis::FirebasehostingV1beta1::ActingUser
Contains metadata about the user who performed an action, such as creating a
release or finalizing a version.
Corresponds to the JSON property createUser
1755 1756 1757 |
# File 'lib/google/apis/firebasehosting_v1beta1/classes.rb', line 1755 def create_user @create_user end |
#delete_time ⇒ String
Output only. The time at which the version was DELETED.
Corresponds to the JSON property deleteTime
1760 1761 1762 |
# File 'lib/google/apis/firebasehosting_v1beta1/classes.rb', line 1760 def delete_time @delete_time end |
#delete_user ⇒ Google::Apis::FirebasehostingV1beta1::ActingUser
Contains metadata about the user who performed an action, such as creating a
release or finalizing a version.
Corresponds to the JSON property deleteUser
1766 1767 1768 |
# File 'lib/google/apis/firebasehosting_v1beta1/classes.rb', line 1766 def delete_user @delete_user end |
#file_count ⇒ Fixnum
Output only. The total number of files associated with the version. This value
is calculated after a version is FINALIZED.
Corresponds to the JSON property fileCount
1772 1773 1774 |
# File 'lib/google/apis/firebasehosting_v1beta1/classes.rb', line 1772 def file_count @file_count end |
#finalize_time ⇒ String
Output only. The time at which the version was FINALIZED.
Corresponds to the JSON property finalizeTime
1777 1778 1779 |
# File 'lib/google/apis/firebasehosting_v1beta1/classes.rb', line 1777 def finalize_time @finalize_time end |
#finalize_user ⇒ Google::Apis::FirebasehostingV1beta1::ActingUser
Contains metadata about the user who performed an action, such as creating a
release or finalizing a version.
Corresponds to the JSON property finalizeUser
1783 1784 1785 |
# File 'lib/google/apis/firebasehosting_v1beta1/classes.rb', line 1783 def finalize_user @finalize_user end |
#labels ⇒ Hash<String,String>
The labels used for extra metadata and/or filtering.
Corresponds to the JSON property labels
1788 1789 1790 |
# File 'lib/google/apis/firebasehosting_v1beta1/classes.rb', line 1788 def labels @labels end |
#name ⇒ String
The fully-qualified resource name for the version, in the format: sites/
SITE_ID/versions/VERSION_ID This name is provided in the response body when
you call CreateVersion.
Corresponds to the JSON property name
1795 1796 1797 |
# File 'lib/google/apis/firebasehosting_v1beta1/classes.rb', line 1795 def name @name end |
#status ⇒ String
The deploy status of the version. For a successful deploy, call
CreateVersion to make a new version (CREATED status)
, upload all desired files to the version,
then update the version to the FINALIZED status.
Note that if you leave the version in the CREATED state for more than 12
hours, the system will automatically mark the version as ABANDONED. You can
also change the status of a version to DELETED by calling DeleteVersion.
Corresponds to the JSON property status
1807 1808 1809 |
# File 'lib/google/apis/firebasehosting_v1beta1/classes.rb', line 1807 def status @status end |
#version_bytes ⇒ Fixnum
Output only. The total stored bytesize of the version. This value is
calculated after a version is FINALIZED.
Corresponds to the JSON property versionBytes
1813 1814 1815 |
# File 'lib/google/apis/firebasehosting_v1beta1/classes.rb', line 1813 def version_bytes @version_bytes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1820 1821 1822 1823 1824 1825 1826 1827 1828 1829 1830 1831 1832 1833 |
# File 'lib/google/apis/firebasehosting_v1beta1/classes.rb', line 1820 def update!(**args) @config = args[:config] if args.key?(:config) @create_time = args[:create_time] if args.key?(:create_time) @create_user = args[:create_user] if args.key?(:create_user) @delete_time = args[:delete_time] if args.key?(:delete_time) @delete_user = args[:delete_user] if args.key?(:delete_user) @file_count = args[:file_count] if args.key?(:file_count) @finalize_time = args[:finalize_time] if args.key?(:finalize_time) @finalize_user = args[:finalize_user] if args.key?(:finalize_user) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @status = args[:status] if args.key?(:status) @version_bytes = args[:version_bytes] if args.key?(:version_bytes) end |